@@ -13,12 +13,7 @@ if __name__ == '__main__':
 else:
     is_pygame_pkg = __name__.startswith('pygame.tests.')
 
-if is_pygame_pkg:
-    from pygame.tests import test_utils
-    from pygame.tests.test_utils import unittest
-else:
-    from test import test_utils
-    from test.test_utils import unittest
+import unittest
 
 class KeyModuleTest(unittest.TestCase):
     def test_get_focused(self):
